import multiprocessing


def func(item, return_val):
    return_val[item] = 'timeout'
    sleep(item)
    return_val[item] = 'Done'
    return 

def timeout_process(item, func, TIMEOUT):
    manager = multiprocessing.Manager()
    return_val = manager.dict()
    proc = multiprocessing.Process(target=func, args=(item,return_val,))
    proc.start()
    
    sec = 0
    
    while sec <= TIMEOUT:
        sleep(1)
        sec+=1
        if not proc.is_alive():
            break


    if proc.is_alive():
        proc.terminate()

    proc.join()

    results = dict(return_val)

    return results



from datetime import datetime as D

def chunkify(lst,n):
    return [lst[i::n].copy() for i in range(n)]

def get_months(start, end):
    s = start.split('_')
    e = end.split('_')
    sy, sm = int(s[0]), int(s[1])
    ey, em = int(e[0]), int(e[1])

    if sy == ey:
        if sm > em:
            return [] 
        if sm == em:
            return [start]
    if ey < sy:
        return []

    dates = []

    while sy < ey:
        if sm < 10:
            dates.append(str(sy) + '_0' + str(sm))
        else:
            dates.append(str(sy) + '_' + str(sm))

        if sm == 12:
            sm = 1
            sy += 1
        else:
            sm += 1


    while sm <= em:
        if sm < 10:
            dates.append(str(sy) + '_0' + str(sm))
        else:
            dates.append(str(sy) + '_' + str(sm))
        sm += 1

    return dates
